==> owncloud_7.0.4+dfsg.orig.tar.bz2: owncloud/apps/files_sharing/l10n/fr.php <==
<?php
$TRANSLATIONS = array(
"Server to server sharing is not enabled on this server" => "Le partage de serveur à serveur n'est pas activé sur ce serveur",
"Couldn't add remote share" => "Impossible d'ajouter un partage distant",
"Shared with you" => "Partagé avec vous",
"Shared with others" => "Partagé avec d'autres",
"Shared by link" => "Partagé par lien",
"No files have been shared with you yet." => "Aucun fichier n'est partagé avec vous pour l'instant",
"You haven't shared any files yet." => "Vous ne partagez pas de fichier pour l'instant",
"You haven't shared any files by link yet." => "Vous ne partagez aucun de fichier par lien pour l'instant.",
"Add {name} from {owner}@{remote}" => "Ajouter {name} de {owner}@{remote}",
"Add Share" => "Ajouter un partage",
"Password" => "Mot de passe",
"No ownCloud installation found at {remote}" => "Aucune installation ownCloud n'a été trouvée sur {remote}",
"Invalid ownCloud url" => "URL ownCloud invalide",
"Shared by {owner}" => "Partagé par {owner}",
"Shared by" => "Partagé par",
"This share is password-protected" => "Ce partage est protégé par un mot de passe",
"The password is wrong. Try again." => "Le mot de passe est incorrect. Veuillez réessayer.",
"Name" => "Nom",
"Share time" => "Date de partage",
"Sorry, this link doesn’t seem to work anymore." => "Désolé, mais le lien semble ne plus fonctionner.",
"Reasons might be:" => "Les raisons peuvent être :",
"the item was removed" => "l'item a été supprimé",
"the link expired" => "le lien a expiré",
"sharing is disabled" => "le partage est désactivé",
"For more info, please ask the person who sent this link." => "Pour plus d'informations, veuillez contacter la personne qui a envoyé ce lien.",
"Save" => "Sauvegarder",
"Download" => "Télécharger",
"Download %s" => "Télécharger %s",
"Direct link" => "Lien direct",
"Remote Shares" => "Partages Distants",
"Allow other instances to mount public links shared from this server" => "Autorise d'autres instances à monter des liens publiques partagés depuis ce serveur",
"Allow users to mount public link shares" => "Autorise les utilisateurs à monter des liens de partages publiques",
"Remote share" => "Partage distant",
"Remote share password" => "Mot de passe du partage distant",
"Do you want to add the remote share {name} from {owner}@{remote}?" => "Voulez-vous ajouter le partage distant {name} de  {owner}@{remote} ?",
"Add remote share" => "Ajouter un partage distant",
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";

==> owncloud_7.0.13~dfsg.orig.tar.bz2: owncloud/apps/files_sharing/l10n/fr.php <==
<?php
$TRANSLATIONS = array(
"Server to server sharing is not enabled on this server" => "Le partage de serveur à serveur n'est pas activé sur ce serveur",
"Couldn't add remote share" => "Impossible d'ajouter un partage distant",
"Shared with you" => "Partagés avec vous",
"Shared with others" => "Partagés avec d'autres",
"Shared by link" => "Partagés par lien",
"No files have been shared with you yet." => "Aucun fichier n'est partagé avec vous pour l'instant.",
"You haven't shared any files yet." => "Vous ne partagez pas de fichier pour l'instant.",
"You haven't shared any files by link yet." => "Vous ne partagez pas de fichier par lien pour l'instant.",
"Add {name} from {owner}@{remote}" => "Ajouter {name} de {owner}@{remote}",
"Add Share" => "Ajouter un partage",
"Password" => "Mot de passe",
"No ownCloud installation found at {remote}" => "Aucune installation ownCloud n'a été trouvée sur {remote}",
"Invalid ownCloud url" => "URL ownCloud invalide",
"Shared by {owner}" => "Partagé par {owner}",
"Shared by" => "Partagé par",
"This share is password-protected" => "Ce partage est protégé par un mot de passe",
"The password is wrong. Try again." => "Le mot de passe est incorrect. Veuillez réessayer.",
"Name" => "Nom",
"Share time" => "Date de partage",
"Sorry, this link doesn’t seem to work anymore." => "Désolé, mais le lien semble ne plus fonctionner.",
"Reasons might be:" => "Les raisons peuvent être :",
"the item was removed" => "l'item a été supprimé",
"the link expired" => "le lien a expiré",
"sharing is disabled" => "le partage est désactivé",
"For more info, please ask the person who sent this link." => "Pour plus d'informations, veuillez contacter la personne qui a envoyé ce lien.",
"Save" => "Sauvegarder",
"Download" => "Télécharger",
"Download %s" => "Télécharger %s",
"Direct link" => "Lien direct",
"Remote Shares" => "Partages Distants",
"Allow other instances to mount public links shared from this server" => "Autorise d'autres instances à monter des liens publiques partagés depuis ce serveur",
"Allow users to mount public link shares" => "Autorise les utilisateurs à monter des liens de partages publiques",
"Remote share" => "Partage distant",
"Remote share password" => "Mot de passe du partage distant",
"Do you want to add the remote share {name} from {owner}@{remote}?" => "Voulez-vous ajouter le partage distant {name} de  {owner}@{remote} ?",
"Add remote share" => "Ajouter un partage distant",
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
